@@ -189,9 +189,9 @@ def create_split_tfrecords_data(data_dir, outfile1name, output1folder, outfile2n
 		
 		zip_file = zipfile.ZipFile('data' + '.zip', 'w')
 		with zip_file:
-			for file in train_files:
+			for file in folder1_files:
 				zip_file.write(file)
-			for file in val_files:
+			for file in folder2_files:
 				zip_file.write(file)
 	
 	print("Data Successfully created!")
